m_librarian.web.app module — Документация m_Librarian 0.1.2

# m_librarian.web.app module

`m_librarian.web.app.` `books_by_author`(*args, **kwargs)

`m_librarian.web.app.` `decode`(value)

`m_librarian.web.app.` `download_book`(*args, **kwargs)

`m_librarian.web.app.` `index`(*args, **kwargs)

`m_librarian.web.app.` `search_authors_get`(*args, **kwargs)

`m_librarian.web.app.` `search_authors_post`(*args, **kwargs)

`m_librarian.web.app.` `send_static`(filename)